==> flo-check-homework-0.9.11.tar.bz2: flo-check-homework-0.9.11/flo-check-homework.fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
<context>
    <name>HomeWorkCheckApp</name>
    <message>
        <location filename="flo_check_homework/main.py" line="244"/>
        <source>Unable to obtain a location of type &lt;i&gt;CacheLocation&lt;/i&gt; with QtGui.QDesktopServices.storageLocation().</source>
        <translation>Impossible d&apos;obtenir un emplacement de type &lt;i&gt;CacheLocation&lt;/i&gt; via QtGui.QDesktopServices.storageLocation().</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="337"/>
        <source>{excMsg}

Another instance of &apos;{prog}&apos; has acquired the lock file &apos;{lock}&apos;, but it is impossible to read that file in order to determine the PID of the other instance (for the reason indicated above). This can happen for instance if the lock file was removed by the other instance between the moment we tried to create it and the moment we tried to read it.

Remedy: check that all instances of &apos;{prog}&apos; are closed and remove the lock file manually if it still exists.</source>
        <translation>{excMsg}

Une autre instance de &apos;{prog}&apos; a acquis le fichier verrou &apos;{lock}&apos; mais il est impossible de lire ce dernier pour déterminer le PID de cette autre instance (pour la raison indiquée ci-dessus). Ceci peut se produire par exemple si le fichier verrou a été effacé par l&apos;autre instance entre le moment où nous avons cherché à le créer et celui où nous avons essayé de le lire.

Remède : vérifiez que toutes les instances de &apos;{prog}&apos; sont fermées et effacez le fichier verrou s&apos;il existe encore.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="383"/>
        <source>The configuration file &lt;i&gt;{0}&lt;/i&gt; was written in an old format. Please remove or rename this file before restarting &lt;i&gt;{1}&lt;/i&gt;.</source>
        <translation>Le fichier de configuration &lt;i&gt;{0}&lt;/i&gt; utilise un ancien format. Veuillez supprimer ou renommer ce fichier avant de relancer &lt;i&gt;{1}&lt;/i&gt;.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="351"/>
        <source>&lt;p&gt;
It seems there is already a running instance of &lt;i&gt;{prog}&lt;/i&gt; (PID {pid}). If this is not the case, please remove the lock file &lt;tt&gt;{lock}&lt;/tt&gt;.
&lt;/p&gt;

&lt;p&gt;
Because of the monitoring of asked questions (in order, for instance, not to ask the same question twice during a given session), it is not possible to run several instances of &lt;i&gt;{prog}&lt;/i&gt; simultaneously under the same user account.&lt;/p&gt;</source>
        <translation>&lt;p&gt;
Il semble qu&apos;il y ait déjà une instance de &lt;i&gt;{prog}&lt;/i&gt; en cours d&apos;exécution (PID {pid}). Si ce n&apos;est pas le cas, veuillez supprimer le fichier verrou &lt;tt&gt;{lock}&lt;/tt&gt;.
&lt;/p&gt;

&lt;p&gt;
En raison du suivi des questions posées (par exemple, ne pas poser deux fois la même question au cours d&apos;une même session), il n&apos;est pas possible de lancer simultanément plusieurs instances de &lt;i&gt;{prog}&lt;/i&gt; sous le même compte utilisateur.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ImageWindow</name>
    <message>
        <location filename="flo_check_homework/image_widgets.py" line="287"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="flo_check_homework/main.py" line="1011"/>
        <source>Password check</source>
        <translation>Vérification du mot de passe</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1036"/>
        <source>&lt;i&gt;Division&lt;/i&gt; password:</source>
        <translation>Mot de passe &lt;i&gt;divisions&lt;/i&gt; :</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1043"/>
        <source>&lt;i&gt;Multiplication&lt;/i&gt; password:</source>
        <translation>Mot de passe &lt;i&gt;multiplications&lt;/i&gt; :</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1049"/>
        <source>&lt;i&gt;Addition&lt;/i&gt; password:</source>
        <translation>Mot de passe &lt;i&gt;additions&lt;/i&gt; :</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1059"/>
        <source>&lt;i&gt;Substraction&lt;/i&gt; password:</source>
        <translation>Mot de passe &lt;i&gt;soustractions&lt;/i&gt; :</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1070"/>
        <source>&amp;Calculus</source>
        <translation>&amp;Calcul</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1092"/>
        <source>C&amp;onjugation</source>
        <translation type="obsolete">C&amp;onjugaison</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1107"/>
        <source>Impossible to exit now.</source>
        <translation>Impossible de quitter maintenant.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1108"/>
        <source>I suggest you to examine the corrections before leaving.</source>
        <translation>Je vous suggère de réviser un peu avant de sortir.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1171"/>
        <source>About {0}</source>
        <translation>À propos de {0}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1123"/>
        <source>Little program that allows one to check and consolidate one&apos;s skills...</source>
        <translation>Petit programme permettant de vérifier et consolider les acquis avant de se détendre...</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1135"/>
        <source>&amp;Test</source>
        <translation>&amp;Test</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1136"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1137"/>
        <source>Test something</source>
        <translation>Tester quelque chose</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1140"/>
        <source>&amp;Launch {0}</source>
        <translation>&amp;Lancer {0}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1143"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1144"/>
        <source>Launch the program {0}</source>
        <translation>Lancer le programme {0}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1151"/>
        <source>&amp;Magic word</source>
        <translation>&amp;Formule magique</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1155"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1156"/>
        <source>Cast a spell</source>
        <translation>Jeter un sort</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1161"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1164"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1167"/>
        <source>Quit the application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1173"/>
        <source>Display information about the program</source>
        <translation>Affiche des informations sur le programme</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1178"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1188"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1192"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1199"/>
        <source>Ready</source>
        <translation>Prêt</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1262"/>
        <source>Wrong password.</source>
        <translation>Mot de passe erroné.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1263"/>
        <source>You must try again and improve your score in order to be allowed to launch {0}!</source>
        <translation>Il faut recommencer et réaliser un meilleur score pour pouvoir lancer {0} !</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1273"/>
        <source>Total score: </source>
        <translation>Score total : </translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1301"/>
        <source>Magic word</source>
        <translation>Formule magique</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1301"/>
        <source>I say {0}. Please enter the magic word.</source>
        <translation>Je dis {0}. Veuillez entrer la formule magique.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1340"/>
        <source>The program &apos;{0}&apos; terminated abnormally (maybe killed by a signal).</source>
        <translation>Le programme &apos;{0}&apos; s&apos;est terminé de manière anormale (peut-être tué par un signal).</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1356"/>
        <source>The program &apos;{0}&apos; could not start; maybe the executable cannot be found or you don&apos;t have the required permissions.</source>
        <translation>Le programme &apos;{0}&apos; n&apos;a pas pu démarrer ; peut-être que l&apos;exécutable est introuvable ou que vous n&apos;avez pas les permissions requises.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1360"/>
        <source>Unknown error while executing the program &apos;{0}&apos; (thanks to Qt for the precise diagnosis).</source>
        <translation>Erreur inconnue lors de l&apos;exécution du programme &apos;{0}&apos; (merci à Qt pour la précision du diagnostic).</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1123"/>
        <source>{progname} {progversion}</source>
        <translation>{progname} {progversion}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1092"/>
        <source>French C&amp;onjugation</source>
        <translation>C&amp;onjugaison</translation>
    </message>
</context>
<context>
    <name>MultipleInputQuestionLine</name>
    <message>
        <location filename="flo_check_homework/main.py" line="524"/>
        <source> Ouch! </source>
        <translation> Aïe ! </translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="527"/>
        <source>Submit</source>
        <translation>Valider</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="547"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="547"/>
        <source>Ouch!</source>
        <translation>Aïe !</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="560"/>
        <source>&lt;nothing&gt;</source>
        <translation>&lt;rien&gt;</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="561"/>
        <source>{0} (not {1})</source>
        <translation>{0} (pas {1})</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="flo_check_homework/main.py" line="813"/>
        <source>Score: </source>
        <translation>Score : </translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="858"/>
        <source>&amp;Submit all</source>
        <translation>&amp;Tout valider</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="flo_check_homework/main.py" line="792"/>
        <source>{0}{1}/{2}</source>
        <translation>{0}{1}/{2}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/exercise_generator.py" line="830"/>
        <source>{0}: </source>
        <translation type="obsolete">{0} : </translation>
    </message>
    <message utf8="true">
        <location filename="flo_check_homework/exercise_generator.py" line="890"/>
        <source>{0} = </source>
        <translation>{0} = </translation>
    </message>
    <message>
        <location filename="flo_check_homework/exercise_generator.py" line="936"/>
        <source>E.D. of {0} by {1}</source>
        <translation>D.E. de {0} par {1}</translation>
    </message>
    <message utf8="true">
        <location filename="flo_check_homework/exercise_generator.py" line="941"/>
        <source>{0}: quotient = </source>
        <translation>{0} : quotient = </translation>
    </message>
    <message utf8="true">
        <location filename="flo_check_homework/exercise_generator.py" line="946"/>
        <source>; remainder = </source>
        <translation> ; reste = </translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1483"/>
        <source>Written by Florent Rougon.

Copyright (c) 2011-2013  Florent Rougon</source>
        <translation>Écrit par Florent Rougon.

Copyright (c) 2011-2013  Florent Rougon</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1486"/>
        <source>This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Ceci est un logiciel libre ; veuillez vous reporter à la distribution source pour les conditions dans lesquelles il peut être copié. Il n&apos;est couvert par AUCUNE GARANTIE, pas même de qualité marchande ou d&apos;adéquation à un besoin particulier.</translation>
    </message>
</context>
</TS>

==> flo-check-homework-0.9.12.tar.bz2: flo-check-homework-0.9.12/flo-check-homework.fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
<context>
    <name>HomeWorkCheckApp</name>
    <message>
        <location filename="flo_check_homework/main.py" line="244"/>
        <source>Unable to obtain a location of type &lt;i&gt;CacheLocation&lt;/i&gt; with QtGui.QDesktopServices.storageLocation().</source>
        <translation>Impossible d&apos;obtenir un emplacement de type &lt;i&gt;CacheLocation&lt;/i&gt; via QtGui.QDesktopServices.storageLocation().</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="342"/>
        <source>{excMsg}

Another instance of &apos;{prog}&apos; has acquired the lock file &apos;{lock}&apos;, but it is impossible to read that file in order to determine the PID of the other instance (for the reason indicated above). This can happen for instance if the lock file was removed by the other instance between the moment we tried to create it and the moment we tried to read it.

Remedy: check that all instances of &apos;{prog}&apos; are closed and remove the lock file manually if it still exists.</source>
        <translation>{excMsg}

Une autre instance de &apos;{prog}&apos; a acquis le fichier verrou &apos;{lock}&apos; mais il est impossible de lire ce dernier pour déterminer le PID de cette autre instance (pour la raison indiquée ci-dessus). Ceci peut se produire par exemple si le fichier verrou a été effacé par l&apos;autre instance entre le moment où nous avons cherché à le créer et celui où nous avons essayé de le lire.

Remède : vérifiez que toutes les instances de &apos;{prog}&apos; sont fermées et effacez le fichier verrou s&apos;il existe encore.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="388"/>
        <source>The configuration file &lt;i&gt;{0}&lt;/i&gt; was written in an old format. Please remove or rename this file before restarting &lt;i&gt;{1}&lt;/i&gt;.</source>
        <translation>Le fichier de configuration &lt;i&gt;{0}&lt;/i&gt; utilise un ancien format. Veuillez supprimer ou renommer ce fichier avant de relancer &lt;i&gt;{1}&lt;/i&gt;.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="356"/>
        <source>&lt;p&gt;
It seems there is already a running instance of &lt;i&gt;{prog}&lt;/i&gt; (PID {pid}). If this is not the case, please remove the lock file &lt;tt&gt;{lock}&lt;/tt&gt;.
&lt;/p&gt;

&lt;p&gt;
Because of the monitoring of asked questions (in order, for instance, not to ask the same question twice during a given session), it is not possible to run several instances of &lt;i&gt;{prog}&lt;/i&gt; simultaneously under the same user account.&lt;/p&gt;</source>
        <translation>&lt;p&gt;
Il semble qu&apos;il y ait déjà une instance de &lt;i&gt;{prog}&lt;/i&gt; en cours d&apos;exécution (PID {pid}). Si ce n&apos;est pas le cas, veuillez supprimer le fichier verrou &lt;tt&gt;{lock}&lt;/tt&gt;.
&lt;/p&gt;

&lt;p&gt;
En raison du suivi des questions posées (par exemple, ne pas poser deux fois la même question au cours d&apos;une même session), il n&apos;est pas possible de lancer simultanément plusieurs instances de &lt;i&gt;{prog}&lt;/i&gt; sous le même compte utilisateur.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ImageWindow</name>
    <message>
        <location filename="flo_check_homework/image_widgets.py" line="287"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="flo_check_homework/main.py" line="1018"/>
        <source>Password check</source>
        <translation>Vérification du mot de passe</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1043"/>
        <source>&lt;i&gt;Division&lt;/i&gt; password:</source>
        <translation>Mot de passe &lt;i&gt;divisions&lt;/i&gt; :</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1050"/>
        <source>&lt;i&gt;Multiplication&lt;/i&gt; password:</source>
        <translation>Mot de passe &lt;i&gt;multiplications&lt;/i&gt; :</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1056"/>
        <source>&lt;i&gt;Addition&lt;/i&gt; password:</source>
        <translation>Mot de passe &lt;i&gt;additions&lt;/i&gt; :</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1066"/>
        <source>&lt;i&gt;Substraction&lt;/i&gt; password:</source>
        <translation>Mot de passe &lt;i&gt;soustractions&lt;/i&gt; :</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1077"/>
        <source>&amp;Calculus</source>
        <translation>&amp;Calcul</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1092"/>
        <source>C&amp;onjugation</source>
        <translation type="obsolete">C&amp;onjugaison</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1114"/>
        <source>Impossible to exit now.</source>
        <translation>Impossible de quitter maintenant.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1115"/>
        <source>I suggest you to examine the corrections before leaving.</source>
        <translation>Je vous suggère de réviser un peu avant de sortir.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1178"/>
        <source>About {0}</source>
        <translation>À propos de {0}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1130"/>
        <source>Little program that allows one to check and consolidate one&apos;s skills...</source>
        <translation>Petit programme permettant de vérifier et consolider les acquis avant de se détendre...</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1142"/>
        <source>&amp;Test</source>
        <translation>&amp;Test</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1143"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1144"/>
        <source>Test something</source>
        <translation>Tester quelque chose</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1147"/>
        <source>&amp;Launch {0}</source>
        <translation>&amp;Lancer {0}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1150"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1151"/>
        <source>Launch the program {0}</source>
        <translation>Lancer le programme {0}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1158"/>
        <source>&amp;Magic word</source>
        <translation>&amp;Formule magique</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1162"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1163"/>
        <source>Cast a spell</source>
        <translation>Jeter un sort</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1168"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1171"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1174"/>
        <source>Quit the application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1180"/>
        <source>Display information about the program</source>
        <translation>Affiche des informations sur le programme</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1185"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1195"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1199"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1206"/>
        <source>Ready</source>
        <translation>Prêt</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1269"/>
        <source>Wrong password.</source>
        <translation>Mot de passe erroné.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1270"/>
        <source>You must try again and improve your score in order to be allowed to launch {0}!</source>
        <translation>Il faut recommencer et réaliser un meilleur score pour pouvoir lancer {0} !</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1280"/>
        <source>Total score: </source>
        <translation>Score total : </translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1325"/>
        <source>Magic word</source>
        <translation>Formule magique</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1301"/>
        <source>I say {0}. Please enter the magic word.</source>
        <translation type="obsolete">Je dis {0}. Veuillez entrer la formule magique.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1368"/>
        <source>The program &apos;{0}&apos; terminated abnormally (maybe killed by a signal).</source>
        <translation>Le programme &apos;{0}&apos; s&apos;est terminé de manière anormale (peut-être tué par un signal).</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1384"/>
        <source>The program &apos;{0}&apos; could not start; maybe the executable cannot be found or you don&apos;t have the required permissions.</source>
        <translation>Le programme &apos;{0}&apos; n&apos;a pas pu démarrer ; peut-être que l&apos;exécutable est introuvable ou que vous n&apos;avez pas les permissions requises.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1388"/>
        <source>Unknown error while executing the program &apos;{0}&apos; (thanks to Qt for the precise diagnosis).</source>
        <translation>Erreur inconnue lors de l&apos;exécution du programme &apos;{0}&apos; (merci à Qt pour la précision du diagnostic).</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1130"/>
        <source>{progname} {progversion}</source>
        <translation>{progname} {progversion}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1099"/>
        <source>French C&amp;onjugation</source>
        <translation>C&amp;onjugaison</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1305"/>
        <source>Too many failed attempts for the magic word</source>
        <translation type="obsolete">Trop de tentatives infructueuses pour la formule magique</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1325"/>
        <source>I say {0} and {1}. Please enter the magic word.</source>
        <translation>Je dis {0} et {1}. Veuillez entrer la formule magique.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1310"/>
        <source>Too many failed attempts for the magic word.</source>
        <translation>Trop de tentatives infructueuses pour la formule magique.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1312"/>
        <source>After {0} failed attempts, the magic wand stops working.</source>
        <translation>Après {0} formules ratées, la baguette magique ne fonctionne plus.</translation>
    </message>
</context>
<context>
    <name>MultipleInputQuestionLine</name>
    <message>
        <location filename="flo_check_homework/main.py" line="529"/>
        <source> Ouch! </source>
        <translation> Aïe ! </translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="532"/>
        <source>Submit</source>
        <translation>Valider</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="552"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="552"/>
        <source>Ouch!</source>
        <translation>Aïe !</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="565"/>
        <source>&lt;nothing&gt;</source>
        <translation>&lt;rien&gt;</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="566"/>
        <source>{0} (not {1})</source>
        <translation>{0} (pas {1})</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="flo_check_homework/main.py" line="818"/>
        <source>Score: </source>
        <translation>Score : </translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="863"/>
        <source>&amp;Submit all</source>
        <translation>&amp;Tout valider</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="flo_check_homework/main.py" line="797"/>
        <source>{0}{1}/{2}</source>
        <translation>{0}{1}/{2}</translation>
    </message>
    <message>
        <location filename="flo_check_homework/exercise_generator.py" line="830"/>
        <source>{0}: </source>
        <translation type="obsolete">{0} : </translation>
    </message>
    <message utf8="true">
        <location filename="flo_check_homework/exercise_generator.py" line="890"/>
        <source>{0} = </source>
        <translation>{0} = </translation>
    </message>
    <message>
        <location filename="flo_check_homework/exercise_generator.py" line="936"/>
        <source>E.D. of {0} by {1}</source>
        <translation>D.E. de {0} par {1}</translation>
    </message>
    <message utf8="true">
        <location filename="flo_check_homework/exercise_generator.py" line="941"/>
        <source>{0}: quotient = </source>
        <translation>{0} : quotient = </translation>
    </message>
    <message utf8="true">
        <location filename="flo_check_homework/exercise_generator.py" line="946"/>
        <source>; remainder = </source>
        <translation> ; reste = </translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1506"/>
        <source>Written by Florent Rougon.

Copyright (c) 2011-2013  Florent Rougon</source>
        <translation type="obsolete">Écrit par Florent Rougon.

Copyright (c) 2011-2013  Florent Rougon</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1514"/>
        <source>This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Ceci est un logiciel libre ; veuillez vous reporter à la distribution source pour les conditions dans lesquelles il peut être copié. Il n&apos;est couvert par AUCUNE GARANTIE, pas même de qualité marchande ou d&apos;adéquation à un besoin particulier.</translation>
    </message>
    <message>
        <location filename="flo_check_homework/main.py" line="1511"/>
        <source>Written by Florent Rougon.

Copyright (c) 2011-2014  Florent Rougon</source>
        <translation>Écrit par Florent Rougon.

Copyright (c) 2011-2014  Florent Rougon</translation>
    </message>
</context>
</TS>
